==> odclib-1.6.0-cp310-cp310-macosx_13_0_x86_64.whl: odclib/include/odc/odc_ecbuild_config.h <==
/*
 * (C) Copyright 2011- ECMWF.
 *
 * This software is licensed under the terms of the Apache Licence Version 2.0
 * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
 * In applying this licence, ECMWF does not waive the privileges and immunities
 * granted to it by virtue of its status as an intergovernmental organisation nor
 * does it submit to any jurisdiction.
 */

#ifndef ODC_ecbuild_config_h
#define ODC_ecbuild_config_h

/* ecbuild info */

#ifndef ECBUILD_VERSION_STR
#define ECBUILD_VERSION_STR "3.8.4"
#endif
#ifndef ECBUILD_VERSION
#define ECBUILD_VERSION "3.8.4"
#endif
#ifndef ECBUILD_MACROS_DIR
#define ECBUILD_MACROS_DIR  "/usr/local/share/ecbuild/cmake"
#endif

/* config info */

#define ODC_OS_NAME          "Darwin-22.5.0"
#define ODC_OS_BITS          64
#define ODC_OS_BITS_STR      "64"
#define ODC_OS_STR           "macosx.64"
#define ODC_OS_VERSION       "22.5.0"
#define ODC_SYS_PROCESSOR    "x86_64"

#define ODC_BUILD_TIMESTAMP  "20250217102812"
#define ODC_BUILD_TYPE       "RelWithDebInfo"

#define ODC_C_COMPILER_ID      "AppleClang"
#define ODC_C_COMPILER_VERSION "14.0.3.14030022"

#define ODC_CXX_COMPILER_ID      "AppleClang"
#define ODC_CXX_COMPILER_VERSION "14.0.3.14030022"

#define ODC_C_COMPILER       "/Library/Developer/CommandLineTools/usr/bin/cc"
#define ODC_C_FLAGS          " -pipe -O2 -g -DNDEBUG"

#define ODC_CXX_COMPILER     "/Library/Developer/CommandLineTools/usr/bin/c++"
#define ODC_CXX_FLAGS        " -pipe -Wall -Wextra -Wno-unused-parameter -Wno-unused-variable -Wno-sign-compare -O2 -g -DNDEBUG"

/* Needed for finding per package config files */

#define ODC_INSTALL_DIR       "/tmp/odc/target/odc"
#define ODC_INSTALL_BIN_DIR   "/tmp/odc/target/odc/bin"
#define ODC_INSTALL_LIB_DIR   "/tmp/odc/target/odc/lib"
#define ODC_INSTALL_DATA_DIR  "/tmp/odc/target/odc/share/odc"

#define ODC_DEVELOPER_SRC_DIR "/opt/actions-runner/work/_work/odc/odc/proj"
#define ODC_DEVELOPER_BIN_DIR "/tmp/odc/build"

/* Fortran support */

#if 0

#define ODC_Fortran_COMPILER_ID      ""
#define ODC_Fortran_COMPILER_VERSION ""

#define ODC_Fortran_COMPILER ""
#define ODC_Fortran_FLAGS    ""

#endif

#endif /* ODC_ecbuild_config_h */

==> odclib-1.6.2.dev20250521-cp310-cp310-macosx_13_0_x86_64.whl: odclib/include/odc/odc_ecbuild_config.h <==
/*
 * (C) Copyright 2011- ECMWF.
 *
 * This software is licensed under the terms of the Apache Licence Version 2.0
 * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
 * In applying this licence, ECMWF does not waive the privileges and immunities
 * granted to it by virtue of its status as an intergovernmental organisation nor
 * does it submit to any jurisdiction.
 */

#ifndef ODC_ecbuild_config_h
#define ODC_ecbuild_config_h

/* ecbuild info */

#ifndef ECBUILD_VERSION_STR
#define ECBUILD_VERSION_STR "3.10.0"
#endif
#ifndef ECBUILD_VERSION
#define ECBUILD_VERSION "3.10.0"
#endif
#ifndef ECBUILD_MACROS_DIR
#define ECBUILD_MACROS_DIR  "/opt/actions-runner/work/_work/python-develop-bundle/python-develop-bundle/ecbuild/cmake"
#endif

/* config info */

#define ODC_OS_NAME          "Darwin-22.5.0"
#define ODC_OS_BITS          64
#define ODC_OS_BITS_STR      "64"
#define ODC_OS_STR           "macosx.64"
#define ODC_OS_VERSION       "22.5.0"
#define ODC_SYS_PROCESSOR    "x86_64"

#define ODC_BUILD_TIMESTAMP  "20250521111117"
#define ODC_BUILD_TYPE       "RelWithDebInfo"

#define ODC_C_COMPILER_ID      "AppleClang"
#define ODC_C_COMPILER_VERSION "14.0.3.14030022"

#define ODC_CXX_COMPILER_ID      "AppleClang"
#define ODC_CXX_COMPILER_VERSION "14.0.3.14030022"

#define ODC_C_COMPILER       "/Library/Developer/CommandLineTools/usr/bin/cc"
#define ODC_C_FLAGS          " -pipe -O2 -g -DNDEBUG"

#define ODC_CXX_COMPILER     "/Library/Developer/CommandLineTools/usr/bin/c++"
#define ODC_CXX_FLAGS        " -pipe -Wall -Wextra -Wno-unused-parameter -Wno-unused-variable -Wno-sign-compare -O2 -g -DNDEBUG"

/* Needed for finding per package config files */

#define ODC_INSTALL_DIR       "/tmp/odc/target/odc"
#define ODC_INSTALL_BIN_DIR   "/tmp/odc/target/odc/bin"
#define ODC_INSTALL_LIB_DIR   "/tmp/odc/target/odc/lib"
#define ODC_INSTALL_DATA_DIR  "/tmp/odc/target/odc/share/odc"

#define ODC_DEVELOPER_SRC_DIR "/opt/actions-runner/work/_work/python-develop-bundle/python-develop-bundle/src/eckit/src/fckit/src/eccodes/src/atlas/src/metkit/src/fdb/src/mir/src/multio/src/odc"
#define ODC_DEVELOPER_BIN_DIR "/tmp/odc/build"

/* Fortran support */

#if 0

#define ODC_Fortran_COMPILER_ID      ""
#define ODC_Fortran_COMPILER_VERSION ""

#define ODC_Fortran_COMPILER ""
#define ODC_Fortran_FLAGS    ""

#endif

#endif /* ODC_ecbuild_config_h */
